==> rkt_1.4.0%2Bdfsg.orig.tar.xz: rkt-1.4.0/stage1/init/common/path.go <==
// Copyright 2014 The rkt Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

//+build linux

package common

import (
	"path/filepath"

	"github.com/appc/spec/schema/types"
	"github.com/coreos/go-systemd/unit"
	"github.com/coreos/rkt/common"
)

const (
	// UnitsDir is the default path to systemd systemd unit directory
	UnitsDir        = "/usr/lib/systemd/system"
	envDir          = "/rkt/env" // TODO(vc): perhaps this doesn't belong in /rkt?
	defaultWantsDir = UnitsDir + "/default.target.wants"
	socketsWantsDir = UnitsDir + "/sockets.target.wants"
)

// ServiceUnitName returns a systemd service unit name for the given app name.
func ServiceUnitName(appName types.ACName) string {
	return appName.String() + ".service"
}

// ServiceUnitPath returns the path to the systemd service file for the given
// app name.
func ServiceUnitPath(root string, appName types.ACName) string {
	return filepath.Join(common.Stage1RootfsPath(root), UnitsDir, ServiceUnitName(appName))
}

// RelEnvFilePath returns the path to the environment file for the given app name
// relative to the pod's root.
func RelEnvFilePath(appName types.ACName) string {
	return filepath.Join(envDir, appName.String())
}

// EnvFilePath returns the path to the environment file for the given app name.
func EnvFilePath(root string, appName types.ACName) string {
	return filepath.Join(common.Stage1RootfsPath(root), RelEnvFilePath(appName))
}

// ServiceWantPath returns the systemd default.target want symlink path for the
// given app name.
func ServiceWantPath(root string, appName types.ACName) string {
	return filepath.Join(common.Stage1RootfsPath(root), defaultWantsDir, ServiceUnitName(appName))
}

// InstantiatedPrepareAppUnitName returns the systemd service unit name for prepare-app
// instantiated for the given root.
func InstantiatedPrepareAppUnitName(appName types.ACName) string {
	// Naming respecting escaping rules, see systemd.unit(5) and systemd-escape(1)
	escapedRoot := unit.UnitNamePathEscape(common.RelAppRootfsPath(appName))
	return "prepare-app@" + escapedRoot + ".service"
}

// SocketUnitName returns a systemd socket unit name for the given app name.
func SocketUnitName(appName types.ACName) string {
	return appName.String() + ".socket"
}

// SocketUnitPath returns the path to the systemd socket file for the given app name.
func SocketUnitPath(root string, appName types.ACName) string {
	return filepath.Join(common.Stage1RootfsPath(root), UnitsDir, SocketUnitName(appName))
}

// SocketWantPath returns the systemd sockets.target.wants symlink path for the
// given app name.
func SocketWantPath(root string, appName types.ACName) string {
	return filepath.Join(common.Stage1RootfsPath(root), socketsWantsDir, SocketUnitName(appName))
}

==> rkt_1.9.1%2Bdfsg.orig.tar.xz: rkt-1.9.1/stage1/init/common/path.go <==
// Copyright 2014 The rkt Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

//+build linux

package common

import (
	"path/filepath"

	"github.com/appc/spec/schema/types"
	"github.com/coreos/go-systemd/unit"
	"github.com/coreos/rkt/common"
)

const (
	// UnitsDir is the default path to systemd systemd unit directory
	UnitsDir        = "/usr/lib/systemd/system"
	envDir          = "/rkt/env" // TODO(vc): perhaps this doesn't belong in /rkt?
	defaultWantsDir = UnitsDir + "/default.target.wants"
	socketsWantsDir = UnitsDir + "/sockets.target.wants"
)

// ServiceUnitName returns a systemd service unit name for the given app name.
func ServiceUnitName(appName types.ACName) string {
	return appName.String() + ".service"
}

// ServiceUnitPath returns the path to the systemd service file for the given
// app name.
func ServiceUnitPath(root string, appName types.ACName) string {
	return filepath.Join(common.Stage1RootfsPath(root), UnitsDir, ServiceUnitName(appName))
}

// RelEnvFilePathEnterexec returns the path to the environment file for the given
// app name relative to the pod's root to be parsed by enterexec.
func RelEnvFilePathEnterexec(appName types.ACName) string {
	return filepath.Join(envDir, appName.String())
}

// EnvFilePathEnterexec returns the path to the environment file for the given
// app name to be parsed by enterexec.
func EnvFilePathEnterexec(root string, appName types.ACName) string {
	return filepath.Join(common.Stage1RootfsPath(root), RelEnvFilePathEnterexec(appName))
}

// RelEnvFilePathSystemd returns the path to the environment file for the given
// app name relative to the pod's root to be parsed by systemd.
func RelEnvFilePathSystemd(appName types.ACName) string {
	return filepath.Join(envDir, appName.String()) + "-systemd"
}

// EnvFilePathSystemd returns the path to the environment file for the given
// app name to be parsed by systemd.
func EnvFilePathSystemd(root string, appName types.ACName) string {
	return EnvFilePathEnterexec(root, appName) + "-systemd"
}

// ServiceWantPath returns the systemd default.target want symlink path for the
// given app name.
func ServiceWantPath(root string, appName types.ACName) string {
	return filepath.Join(common.Stage1RootfsPath(root), defaultWantsDir, ServiceUnitName(appName))
}

// InstantiatedPrepareAppUnitName returns the systemd service unit name for prepare-app
// instantiated for the given root.
func InstantiatedPrepareAppUnitName(appName types.ACName) string {
	// Naming respecting escaping rules, see systemd.unit(5) and systemd-escape(1)
	escapedRoot := unit.UnitNamePathEscape(common.RelAppRootfsPath(appName))
	return "prepare-app@" + escapedRoot + ".service"
}

// SocketUnitName returns a systemd socket unit name for the given app name.
func SocketUnitName(appName types.ACName) string {
	return appName.String() + ".socket"
}

// SocketUnitPath returns the path to the systemd socket file for the given app name.
func SocketUnitPath(root string, appName types.ACName) string {
	return filepath.Join(common.Stage1RootfsPath(root), UnitsDir, SocketUnitName(appName))
}

// SocketWantPath returns the systemd sockets.target.wants symlink path for the
// given app name.
func SocketWantPath(root string, appName types.ACName) string {
	return filepath.Join(common.Stage1RootfsPath(root), socketsWantsDir, SocketUnitName(appName))
}
